﻿// <copyright file="AcknowledgeNotWantedError.cs" company="Hallvard Korsgaard">
//  Microsoft Public License (Ms-PL). See license details here: http://enoceannet.codeplex.com/license
// </copyright>
// <author>Hallvard Korsgaard</author> 

namespace EnOcean.Message.Error
{
  using System;

  /// <summary>
  /// When a 6DT modem telegram has been sent, the TCM waits for a ModemAcknowledgeTelegram. This error message is 
  /// generated if an MDA with the right modem ID is received after the timeout (100ms) or if there is more than one ModemAcknowledgeTelegram received. 
  /// </summary>
  [Serializable]
  public class AcknowledgeNotWantedError : Error
  {
    /// <summary>
    /// Creates the byte format of the message.
    /// </summary>
    /// <param name="message">A byte array of length 14 to hold the message contents.</param>
    protected internal override void CreateMessage(byte[] message)
    {
      base.CreateMessage(message);
      message[3] = (byte)MessageType.AcknowledgeNotWantedError;
    }
  }
}
