﻿// <copyright file="NoAcknowledgeError.cs" company="Hallvard Korsgaard">
//  Microsoft Public License (Ms-PL). See license details here: http://enoceannet.codeplex.com/license
// </copyright>
// <author>Hallvard Korsgaard</author>

namespace EnOcean.Message.Error
{
  using System;

  /// <summary>
  /// When a 6DT modem telegram has been sent, the TCM waits for a ModemAcknowledgeTelegram. This error message is 
  /// generated if no acknowledge was received before the timeout (100ms).
  /// </summary>
  [Serializable]
  public class NoAcknowledgeError : Error
  {
    /// <summary>
    /// Creates the byte format of the message.
    /// </summary>
    /// <param name="message">A byte array of length 14 to hold the message contents.</param>
    protected internal override void CreateMessage(byte[] message)
    {
      base.CreateMessage(message);
      message[3] = (byte)MessageType.NoAcknowledgeError;
    }
  }
}
