﻿// <copyright file="InformIdBase.cs" company="Hallvard Korsgaard">
//  Microsoft Public License (Ms-PL). See license details here: http://enoceannet.codeplex.com/license
// </copyright>
// <author>Hallvard Korsgaard</author> 

namespace EnOcean.Message
{
  using System;

  /// <summary>
  /// This message informs the user about the ID range base number. 
  /// </summary>
  [Serializable]
  public class InformIdBase : MessageTelegram
  {
    /// <summary>
    /// Variable for the IdBase property.
    /// </summary>
    private long idBase;

    /// <summary>
    /// Gets the 32 bit transmitter ID. The ID must be in the range 0xFF800000 to 0xFFFFFFFF inclusive.
    /// </summary>
    public long IdBase
    {
      get
      {
       return this.idBase;
      }
      
      internal set
      {
        if (value >= 0xFF800000 && value <= 0xFFFFFFFF)
        {
          this.idBase = value;
        }
        else
        {
          throw new ArgumentOutOfRangeException("Id", "must be a 32 bit value in the range 0xFF800000 to 0xFFFFFFFF inclusive");
        }
      }
    }

    /// <summary>
    /// Creates the byte format of the message.
    /// </summary>
    /// <param name="message">A byte array of length 14 to hold the message contents.</param>
    protected internal override void CreateMessage(byte[] message)
    {
      byte[] i;

      base.CreateMessage(message);

      i = BitConverter.GetBytes(this.idBase);
      message[3] = (byte)MessageType.InformIdBase;
      message[4] = i[3]; // Id 3
      message[5] = i[2]; // Id 2
      message[6] = i[1]; // Id 1
      message[7] = i[0]; // Id 0
    }
  }
}
