﻿// <copyright file="Org.cs" company="Hallvard Korsgaard">
//  Microsoft Public License (Ms-PL). See license details here: http://enoceannet.codeplex.com/license
// </copyright>
// <author>Hallvard Korsgaard</author> 

namespace EnOcean
{
  using System;

  /// <summary>
  /// Type of telegram (the ORG byte).
  /// </summary>
  [Serializable]
  public enum Org : byte
  {
    /// <summary>
    /// Telegram from a PTM switch module received (RPS).
    /// </summary>
    RepeatedSwitch = 0x5,

    /// <summary>
    /// 1 byte data telegram from a STM sensor module (1BS),
    /// </summary>
    OneByteSensor = 0x6,

    /// <summary>
    /// 4 byte data telegram from a STM sensor module (4BS).
    /// </summary>
    FourByteSensor = 0x7,
    
    /// <summary>
    /// Telegram from a CTM module (HRC).
    /// </summary>
    HRC = 0x8,

    /// <summary>
    /// Modem Telegram (6DT).
    /// </summary>
    Modem = 0xA,

    /// <summary>
    /// Modem Acknowledge Telegram (MDA).
    /// </summary>
    ModemAcknowledge = 0xB
  }
}
