﻿// <copyright file="FourByteSensorFunction.cs" company="Hallvard Korsgaard">
//  Microsoft Public License (Ms-PL). See license details here: http://enoceannet.codeplex.com/license
// </copyright>
// <author>Hallvard Korsgaard</author> 

namespace EnOcean.Radio.Sensor
{
  using System;

  /// <summary>
  /// EnOcean equipment profiles for 4 byte telegrams.
  /// </summary>
  [Serializable]
  public enum FourByteSensorFunction : byte
  {
    /// <summary>
    /// Unknown fuction.
    /// </summary>
    Unknown = 0,

    /// <summary>
    /// Temperature sensor.
    /// </summary>
    TemperatureSensor = 0x2,

    /// <summary>
    /// Temperature &amp; humidity sensor.
    /// </summary>
    TemperatureHumiditySensor = 0x4,

    /// <summary>
    /// Pressure sensor.
    /// </summary>
    PressureSensor = 0x5,

    /// <summary>
    /// Light sensor.
    /// </summary>
    LightSensor = 0x6,

    /// <summary>
    /// Occupancy sensor.
    /// </summary>
    OccupancySensor = 0x7,

    /// <summary>
    /// Light, temperature &amp; occupancy sensor.
    /// </summary>
    LightTemperatureOccupancySensor = 0x8,

    /// <summary>
    /// Gas sensor.
    /// </summary>
    GasSensor = 0x9,

    /// <summary>
    /// Room operating panel.
    /// </summary>
    RoomOperatingPanel = 0x10,

    /// <summary>
    /// Controller status.
    /// </summary>
    ControllerStatus = 0x11,

    /// <summary>
    /// Digital input.
    /// </summary>
    DigitalInput = 0x30,

    /// <summary>
    /// Central command.
    /// </summary>
    CentralCommand = 0x38,

    /// <summary>
    /// Universal function.
    /// </summary>
    Universal = 0x3F
  }
}
