﻿// <copyright file="SetAlarm.cs" company="Hallvard Korsgaard">
//  Microsoft Public License (Ms-PL). See license details here: http://enoceannet.codeplex.com/license
// </copyright>
// <author>Hallvard Korsgaard</author>

namespace StcEthernet.Management
{
  using System;

  /// <summary>
  /// Sets the STC-Ethernet alarm time.
  /// </summary>
  [Serializable]
  public class SetAlarm : ManagementTelegram
  {
    /// <summary>
    /// Initializes a new instance of the SetAlarm class.
    /// </summary>
    public SetAlarm()
      : this(16)
    {
    }

    /// <summary>
    /// Initializes a new instance of the SetAlarm class.
    /// </summary>
    /// <param name="minutes">The alarm time in minutes.</param>
    public SetAlarm(byte minutes)
    {
      this.Minutes = minutes;
    }

    /// <summary>
    /// Gets or sets the alarm time.
    /// </summary>
    public byte Minutes
    {
      get;
      set;
    }

    /// <summary>
    /// Creates the byte format of the message.
    /// </summary>
    /// <param name="message">A byte array of length 10 to hold the message contents.</param>
    protected internal override void CreateMessage(byte[] message)
    {
      base.CreateMessage(message);
      message[2] = 0x9A;
      message[3] = this.Minutes;
      message[4] = 0x01;
      message[5] = 0x02;
      message[6] = 0x03;
      message[7] = 0x04;
      message[8] = 0x05;
      message[9] = 0x06;
    }
  }
}
