﻿// <copyright file="SetLearnMode.cs" company="Hallvard Korsgaard">
//  Microsoft Public License (Ms-PL). See license details here: http://enoceannet.codeplex.com/license
// </copyright>
// <author>Hallvard Korsgaard</author>

namespace StcEthernet.Management
{
  using System;
  using EnOcean;

  /// <summary>
  /// Sets the transiever in learn mode.
  /// </summary>
  [Serializable]
  public class SetLearnMode : ManagementTelegram
  {
    /// <summary>
    /// Initializes a new instance of the SetLearnMode class.
    /// </summary>
    public SetLearnMode()
    {
    }
      
    /// <summary>
    /// Initializes a new instance of the SetLearnMode class.
    /// </summary>
    /// <param name="org">The org byte value.</param>
    /// <param name="channel">The transiever channel to program.</param>
    public SetLearnMode(Org org, byte channel)
    {
      this.Org = org;
      this.Channel = channel;
    }

    /// <summary>
    /// Gets or sets the org byte.
    /// </summary>
    public Org Org
    {
      get;
      set;
    }
    
    /// <summary>
    /// Gets or sets the channel to use for this transmitter.
    /// </summary>
    public byte Channel
    {
      get;
      set;
    }

    /// <summary>
    /// Creates the byte format of the message.
    /// </summary>
    /// <param name="message">A byte array of length 10 to hold the message contents.</param>
    protected internal override void CreateMessage(byte[] message)
    {
      base.CreateMessage(message);

      message[2] = 0x91;
      message[3] = this.Channel;
      message[4] = (byte)Org;
      message[5] = 0x02;
      message[6] = 0x03;
      message[7] = 0x04;
      message[8] = 0x05;
      message[9] = 0x06;
    }
  }
}
