﻿// <copyright file="SetMode.cs" company="Hallvard Korsgaard">
//  Microsoft Public License (Ms-PL). See license details here: http://enoceannet.codeplex.com/license
// </copyright>
// <author>Hallvard Korsgaard</author>

namespace StcEthernet.Management
{
  using System;

  /// <summary>
  /// Sets the STC-Ethernet module in Normal og Gateway mode.
  /// </summary>
  [Serializable]
  public class SetMode : ManagementTelegram
  {
    /// <summary>
    /// Initializes a new instance of the SetMode class. The mode is set to Normal.
    /// </summary>
    public SetMode()
      : this(OperatingMode.Normal)
    {
    }

    /// <summary>
    /// Initializes a new instance of the SetMode class.
    /// </summary>
    /// <param name="mode">The operation mode.</param>
    public SetMode(OperatingMode mode)
    {
      this.Mode = mode;
    }

    /// <summary>
    /// Gets or sets the operation mode.
    /// </summary>
    public OperatingMode Mode
    {
      get;
      set;
    }

    /// <summary>
    /// Creates the byte format of the message.
    /// </summary>
    /// <param name="message">A byte array of length 10 to hold the message contents.</param>
    protected internal override void CreateMessage(byte[] message)
    {
      base.CreateMessage(message);
      message[2] = 0x9E;
      message[3] = (byte)this.Mode;
      message[4] = 0x01;
      message[5] = 0x02;
      message[6] = 0x03;
      message[7] = 0x04;
      message[8] = 0x05;
      message[9] = 0x06;
    }
  }
}
